==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Effect/srconverter/translations/srconverter_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Модуль SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="49"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Про модуль Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Модуль Sample Rate Converter для Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Налаштування модуля Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Дискретизація семпла (Гц):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Технологія інтерполяції:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Кращий синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Середній синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Найшвидший синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Інтерполяція ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Лінійна інтерполяція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>&amp;OK</source>
        <translation>&amp;Застосувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Відмінити</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/Effect/srconverter/translations/srconverter_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Модуль SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Про модуль Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Модуль Sample Rate Converter для Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Налаштування модуля Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Дискретизація семпла (Гц):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Технологія інтерполяції:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Кращий синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Середній синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Найшвидший синк інтерполяції</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Інтерполяція ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Лінійна інтерполяція</translation>
    </message>
</context>
</TS>
